PackedFloat32Array class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
nativeDataPtr Pointer<Uint8>
no setterinherited
nativePointerAddress int
Since Pointer.address isn's tagged 'vm:entry-point', supply an entry point that can get the raw pointer address for this object
no setterinherited
nativePtr Pointer<Uint8>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeInfo BuiltinTypeInfo<PackedFloat32Array>
no setteroverride

Methods

allocateOpaque(int size, GDExtensionPtrDestructor? destructor) Pointer<Uint8>
inherited
append(double value) bool
appendArray(PackedFloat32Array array) → void
bsearch(double value, {bool before = true}) int
clear() → void
constructCopy(GDExtensionTypePtr ptr) → void
This is used by the generators to call the FFI copy constructors for builtin types, usually as part of returning them from a ptr call.
override
count(double value) int
duplicate() PackedFloat32Array
fill(double value) → void
find(double value, {int from = 0}) int
has(double value) bool
insert(int atIndex, double value) int
isEmpty() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushBack(double value) bool
removeAt(int index) → void
resize(int newSize) int
reverse() → void
rfind(double value, {int from = -1}) int
set(int index, double value) → void
size() int
slice(int begin, {int end = 2147483647}) PackedFloat32Array
sort() → void
toByteArray() PackedByteArray
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) double
operator []=(int index, double value) → void

Static Properties

sTypeInfo BuiltinTypeInfo<PackedFloat32Array>
final

Static Methods

initBindings() → void
initBindingsConstructorDestructor() → void